import { useNuxtApp, useRuntimeConfig } from "#imports";
export function useSegment(segment) {
  const $segment = segment ?? useNuxtApp().$segment;
  const config = useRuntimeConfig().public.segment;
  const logPrefix = shouldTrack() ? "segment" : "segment-mock";
  function shouldTrack() {
    return process.client && (process.env.NODE_ENV !== "development" || config.trackDevMode);
  }
  function identify(...args) {
    wrapFn($segment.identify)(...args);
  }
  function alias(...args) {
    wrapFn($segment.alias)(...args);
  }
  function page(...args) {
    wrapFn($segment.page)(...args);
  }
  function screen(...args) {
    wrapFn($segment.screen)(...args);
  }
  function group(...args) {
    wrapFn($segment.group)(...args);
  }
  function track(...args) {
    wrapFn($segment.track)(...args);
  }
  function trackSubmit(...args) {
    wrapFn($segment.trackSubmit)(...args);
  }
  function trackClick(...args) {
    wrapFn($segment.trackClick)(...args);
  }
  function trackLink(...args) {
    wrapFn($segment.trackLink)(...args);
  }
  function reset(...args) {
    return wrapFn($segment.reset)(...args);
  }
  function raw(name, ...args) {
    return wrapFn($segment[name])(...args);
  }
  function wrapFn(fn) {
    return function analyticsFn(...args) {
      if (config.debugEnabled) {
        console.log(`[${logPrefix}@raw]`, ...args);
      }
      if (shouldTrack()) {
        return fn(...args);
      }
    };
  }
  return {
    $segment,
    identify,
    alias,
    page,
    screen,
    group,
    track,
    trackSubmit,
    trackClick,
    trackLink,
    reset,
    raw
  };
}
